"use client";

import { Card } from "@/components/ui/card";
import {
	Select,
	SelectContent,
	SelectItem,
	SelectTrigger,
	SelectValue,
} from "@/components/ui/select";
import { Skeleton } from "@/components/ui/skeleton";
import { ImageBaseUrl } from "@/configs/api";
import { Link } from "@/i18n/routing";
import { cn } from "@/lib/utils";
import { useCategory } from "@/servers/data/use-category";
import { useGroup } from "@/servers/data/use-group";
import { useProduct } from "@/servers/data/use-product";
import { ChevronRight } from "lucide-react";
import { useLocale, useTranslations } from "next-intl";
import Image from "next/image";
import { useSearchParams } from "next/navigation";
import React, { useEffect, useState } from "react";


export default function ElectronicRecommendations() {

	const t = useTranslations();
	const locale = useLocale();
	const searchParams = useSearchParams();

	const isRTL = locale === "ar";
	const [filters, setFilters] = useState({
		category_id: "all",
		group_id: "all",
	});

	const [_groups, setGroups] = useState([]);
	const [_products, setProducts] = useState([]);

	/*const activeFilters = useMemo(() => {
		return {
			...(filters.category_id !== "all" && { category_id: Number(filters.category_id) }),
			...(filters.group_id !== "all" && { group_id: Number(filters.group_id) })			
		};
	}, [filters]);*/

	const { products, isLoading } = useProduct({});

	const { groups } = useGroup();
	const { categories } = useCategory();

	const _categories = React.useMemo(() => {
		const __catgs = {
			value: "all",
			label: {
				ar: "جميع الفئات",
				en: "All Categories",
			},
		};

		const _options = categories?.map((category: any) => ({
			value: category.id,
			label: {
				ar: category.name_ar,
				en: category.name_en,
			},
		})) || [];

		return [__catgs, ..._options];

	}, [categories]);

	const filterProducts = ({ category_id, group_id }: { category_id: string, group_id: string }) => {
		if (products && category_id !== "all" && group_id !== "all") {
			const __products = products?.filter((product: any) => product.sub_category_id == group_id && product.category_id == category_id);
			setProducts(__products);
		}
	};

	const filterGroups = (category_id: string) => {
		const _options = groups
			?.filter((val: any) => val?.category_id == category_id)
			?.map((group: any) => ({
				value: group.id,
				label: {
					ar: group.name_ar,
					en: group.name_en,
				}
			})) || [];

		setGroups(_options);
		return _options?.[0]?.value;
	};

	const updateFilter = (key: any, value: any) => {
		if (key === "category_id") {
			if (value == "all") setProducts(products?.slice(0, 9) || []);
			else {
				const _group_id = filterGroups(value);
				setFilters({ category_id: value, group_id: _group_id });
				filterProducts({ category_id: value, group_id: _group_id });
			}

		} else {
			setFilters({ category_id: filters.category_id, group_id: value });
			filterProducts({ category_id: filters.category_id, group_id: value });
		}

	};

	useEffect(() => {
		const _category_id = searchParams.get("category_id");
		if (_category_id && products) updateFilter("category_id", parseInt(_category_id));
		else if (products) {
			setProducts(products?.slice(0, 9) || []);
		}

	}, [products, searchParams]);

	// console.log("products: ", _products);

	// console.log("_groups: ", _groups);

	// console.log("_categories: ", _categories);

	console.log("filters: ", filters);

	if (isLoading || !_products) {
		return <SkeletonProduct />;
	}


	return (
		<section className="container mx-auto max-w-7xl px-4 py-16">
			<div className="flex flex-col gap-8">
				{/* Header */}
				<div className="flex items-center justify-between">
					<div className="flex items-center gap-5">
						<h1 className={cn("text-2xl font-bold", isRTL && "text-right")}>
							{t("Products")}
						</h1>
					</div>
					<span className="text-md text-[#2895C8] flex items-center gap-2">
						{t("View More")}
						<ChevronRight className={cn("h-4 w-4", isRTL && "rotate-180 transform")} />
					</span>
				</div>

				<div className="flex flex-col gap-4 md:flex-row md:items-center md:justify-between">
					<div className="grid gap-4 md:grid-cols-4">
						<Select
							value={filters.category_id}
							onValueChange={(value) => updateFilter("category_id", value)}
						>
							<SelectTrigger className="border-[#30303093] text-[#30303093]">
								<SelectValue
									placeholder={t("SelectCategory")}
								/>
							</SelectTrigger>
							<SelectContent>
								{_categories?.map((_categ: any) => (
									<SelectItem
										key={_categ.value}
										value={_categ.value}
										className={
											_categ.value === filters.category_id
												? "text-custom-primary-accent"
												: ""
										}
									>
										{_categ.label?.[locale]}
									</SelectItem>
								))}
							</SelectContent>
						</Select>

						<Select
							value={filters.group_id}
							onValueChange={(value) => updateFilter("group_id", value)}
						>
							<SelectTrigger className="border-[#30303093] text-[#30303093]">
								<SelectValue
									placeholder={t("SelectSubCategory")}
								/>
							</SelectTrigger>
							<SelectContent>
								{_groups?.map((_group: any) => (
									<SelectItem
										key={_group.value}
										value={_group.value}
										className={
											_group.value === filters.group_id
												? "text-custom-primary-accent"
												: ""
										}
									>
										{_group.label?.[locale]}
									</SelectItem>
								))}
							</SelectContent>
						</Select>

						{/*<Select
								value={filters.min_price}
								onValueChange={(value) => updateFilter("min_price", value)}
							>
								<SelectTrigger className="border-[#30303093] text-[#30303093]">
									<SelectValue
										placeholder={t("SelectPriceRange")}
									/>
								</SelectTrigger>
								<SelectContent>
									{[]?.map((range: any) => (
										<SelectItem
											key={range.value}
											value={range.value}
											className={
												range.value === filters.min_price
													? "text-custom-primary-accent"
													: ""
											}
										>
											{range.label?.[locale]}
										</SelectItem>
									))}
								</SelectContent>
							</Select>*/}
					</div>
				</div>

				{/* Products */}
				<div
					className={cn(
						"grid gap-8",
						"sm:grid-cols-1 md:grid-cols-2 lg:grid-cols-3"
					)}
				>
					{_products?.map((product: any) => (
						<Link href={`/products/${product?.product_slug}` as any} key={product?.id}>
							<ProductCard key={product.id} product={product} />
						</Link>
					))}
				</div>

			</div>
		</section>
	);
}


const SkeletonProduct = () => {
	return (
		<section className="container mx-auto max-w-7xl px-4 py-16">
			<div className="flex flex-col gap-8">
				{/* Header Skeleton */}
				<div className="flex flex-col gap-4">
					<div className="flex items-center justify-between">
						<div className="flex items-center gap-2">
							<Skeleton className="h-10 w-10" />
							<Skeleton className="h-10 w-10" />
						</div>
						<Skeleton className="h-8 w-32" />
					</div>
					<div className="grid gap-4 md:grid-cols-4">
						{[1, 2, 3, 4]?.map((index) => (
							<Skeleton key={index} className="h-10 w-full" />
						))}
					</div>
				</div>
				{/* Products Grid Skeleton */}
				<div className="grid gap-6 sm:grid-cols-1 md:grid-cols-2 lg:grid-cols-3">
					{[1, 2, 3, 4, 5, 6]?.map((index) => (
						<Card key={index} className="overflow-hidden border-none">
							<Skeleton className="h-[300px] w-full" />
							<div className="flex flex-col items-center gap-2 p-4">
								<Skeleton className="h-6 w-3/4" />
								<div className="flex items-center gap-2">
									<Skeleton className="h-6 w-20" />
									<Skeleton className="h-4 w-16" />
								</div>
								<Skeleton className="h-10 w-full" />
							</div>
						</Card>
					))}
				</div>
			</div>
		</section>
	);
};


const ProductCard = ({ product }: { product: any }) => {
	const locale = useLocale();
	return (
		<Card className="flex flex-col overflow-hidden rounded-md border-none bg-white shadow-md">
			<div className="relative h-[300px] w-full">
				<Image
					src={ImageBaseUrl + product?.images?.[0]?.image_path}
					alt={product?.images?.[0]?.name}
					fill
					className="object-cover"
				/>
			</div>
			<div className="flex flex-1 flex-col items-center gap-2 p-4">
				<h3 className="text-sm font-semibold text-center">{locale === "ar" ? product?.name_ar : product?.name_en}</h3>
				<div className="flex items-center gap-2">
					<div className="flex items-center gap-2">
						<span className="text-lg font-bold text-[#2895C8]">{product?.base_price}</span>
						<Image src={"/coins/Saudi_Riyal.jpg"} alt="Saudi_Riyal" width={16} height={16} />
					</div>
					{/*<span className="text-sm text-muted-foreground line-through">
						${product?.final_price?.toLocaleString()}
					</span>}*/}
				</div>
			</div>
		</Card>

	);
};

